function [ results ] = test1_rr1l_sfft_algorithm_multipletests( d_array, N_array, signal_sparsity_k, algorithm_name, coeff_randtype, sparsity_s, threshold_theta, niter_r, nruns, filename )
%TEST1_RR1l_SFFT_ALGORITHM_MULTIPLETESTS Runs multiple test sets of random_lattice_sfft_algorithm.
%   This function may run many tests sets with a large amount of repititions.
%
%   Input parameters:
%      d_array - array of dimensions d
%      N_array - array of search space parameters N, Gamma = [-N,..,N]^d
%      signal_sparsity_k - signal sparsity
%      algorithm_name - type of algorithm, use 'rlfftriabs'
%      coeff_randtype - type of random coefficients,
%                       either 'rand' for fhat_k in [-1,1] + 1i*[-1,1]
%                       with |fhat_k| >= 1e-6
%                       or 'phase' for fhat_k = exp(2*pi*1i*phi_k),
%                       phi_k in [0,1)
%      sparsity_s - target sparsity of output
%      threshold_theta - relative threshold theta
%      niter_r - number of detection iterations r
%      nruns - number of repetition for one test setting
%      filename - output file name, where the output results are written to
%
%   Output parameter:
%      results - 3d array of type struct with size
%                [length(N_array), length(d_array), nruns]
%
% Copyright (c) 2015-2020 Toni Volkmer
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 2 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51
% Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

if nargin < 10
  filename = 'test1_results.mat';
end

results = repmat(struct(), length(N_array), length(d_array), nruns);

for iN=1:length(N_array)
  N = N_array(iN);
  for id=1:length(d_array)
    d = d_array(id);
    for ir = 1:nruns
      [ num_freq, num_freq_out, num_intersect, max_err_abs, err_l2_rel, freq_cand_sizes, lattice_sizes, sample_sizes, z, run_times, niter_cg ] ...
        = test1_rr1l_sfft_algorithm_singletest( d, N, signal_sparsity_k, algorithm_name, coeff_randtype, sparsity_s, threshold_theta, niter_r);
      fprintf('run=%2d, N=%3d, d=%2d, k=%6d, k_out=%6d, nfreq_both=%6d, err_abs=%.3e, err_l2_rel=%.3e\n', ir, N, d, num_freq, num_freq_out, num_intersect, max_err_abs, err_l2_rel);
      %drawnow;
      results(iN,id,ir).num_freq = num_freq;
      results(iN,id,ir).num_freq_out = num_freq_out;
      results(iN,id,ir).num_intersect = num_intersect;
      results(iN,id,ir).max_err_abs = max_err_abs;
      results(iN,id,ir).err_l2_rel = err_l2_rel;
      results(iN,id,ir).freq_cand_sizes = freq_cand_sizes;
      results(iN,id,ir).lattice_sizes = lattice_sizes;
      results(iN,id,ir).sample_sizes = sample_sizes;
      results(iN,id,ir).z = z;
      results(iN,id,ir).run_times = run_times; % basic, lattice search, sampling, lfft, all
      results(iN,id,ir).niter_cg = niter_cg;
      save(filename, 'd_array', 'N_array', 'signal_sparsity_k', 'algorithm_name', 'coeff_randtype', 'sparsity_s', 'threshold_theta', 'niter_r', 'nruns', 'results');
    end
  end
end

end
