function [out] = test_alias1ri_plots_results(filename)
%Outputs plot information for tests from Section 4.1.2 and 4.1.3.
%
% Copyright (c) 2020 Toni Volkmer
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 2 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51
% Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.


load(filename);

fprintf('%% %s success_rate(#samples)\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', max(num_samples_matrix(iL,:)), success_rate(iL));
end
fprintf('\n\n');

fprintf('%% %s success_rate(L)\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), success_rate(iL));
end
fprintf('\n\n');

fprintf('%% %s failure_rate(L)\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), 1-success_rate(iL));
end
fprintf('\n\n');

fprintf('%% %s theoretical_failure_rate(L)\n', filename);
for L = 37:2:49
  fprintf(' (%d,%.3f)', L, exp(-(c-2)*log(c-1)/4/c*L+log(card_Gamma)));
end
fprintf('\n\n');

maxFN = max(num_potentially_false_negative_matrix,[],2);
fprintf('%% %s max of potentially FN\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%d)', L_array(iL), maxFN(iL));
end
fprintf('\n\n');

maxFP = max(num_potentially_false_positive_matrix,[],2);
fprintf('%% %s max of potentially FP\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%d)', L_array(iL), maxFP(iL));
end
fprintf('\n\n');

TP1000_FPleq10 = sum((num_true_positive_matrix==1000) .* (num_potentially_false_positive_matrix <= 10),2)/nrepeat;
fprintf('%% %s TP1000 FP<=10\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), TP1000_FPleq10(iL));
end
fprintf('\n\n');

fprintf('%% %s ~(TP1000 FP<=10)\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), 1-TP1000_FPleq10(iL));
end
fprintf('\n\n');

TP1000_FPleq100 = sum((num_true_positive_matrix==1000) .* (num_potentially_false_positive_matrix <= 100),2)/nrepeat;
fprintf('%% %s TP1000 FP<=100\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), TP1000_FPleq100(iL));
end
fprintf('\n\n');

fprintf('%% %s ~(TP1000 FP<=100)\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), 1-TP1000_FPleq100(iL));
end
fprintf('\n\n');


TP1000_FPleq1000 = sum((num_true_positive_matrix==1000) .* (num_potentially_false_positive_matrix <= 1000),2)/nrepeat;
fprintf('%% %s TP1000 FP<=1000\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), TP1000_FPleq1000(iL));
end
fprintf('\n\n');

fprintf('%% %s ~(TP1000 FP<=1000)\n', filename);
for iL = 1:length(L_array)
  fprintf(' (%d,%.3f)', L_array(iL), 1-TP1000_FPleq1000(iL));
end
fprintf('\n\n');

